##  Creating and Editing Tags in a Tag Group
To create tags in a tag group, follow these steps:
  1. Select the tag group in which tags need to be created.
  2. Select the Tags tab.
  3. Click + Add Tag.
  4. Provide a name and click OK.


You can edit a tag to change the color, tag group, name, and description. To edit, do the following:
  1. Select the tag that needs to be edited.
  2. Make the necessary changes.
  3. Click Save.
